package com.yijia.label.mapper;

import java.util.List;
import com.yijia.label.domain.LabelRule;

/**
 * 标签规则
Mapper接口
 * 
 * @author yijia
 * @date 2021-06-15
 */
public interface LabelRuleMapper 
{
    /**
     * 查询标签规则

     * 
     * @param id 标签规则
ID
     * @return 标签规则

     */
    public LabelRule selectLabelRuleById(Integer id);

    /**
     * 查询标签规则
列表
     * 
     * @param labelRule 标签规则

     * @return 标签规则
集合
     */
    public List<LabelRule> selectLabelRuleList(LabelRule labelRule);

    /**
     * 新增标签规则

     * 
     * @param labelRule 标签规则

     * @return 结果
     */
    public int insertLabelRule(LabelRule labelRule);

    /**
     * 修改标签规则

     * 
     * @param labelRule 标签规则

     * @return 结果
     */
    public int updateLabelRule(LabelRule labelRule);

    /**
     * 删除标签规则

     * 
     * @param id 标签规则
ID
     * @return 结果
     */
    public int deleteLabelRuleById(Integer id);

    /**
     * 批量删除标签规则

     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteLabelRuleByIds(Integer[] ids);
}
